@@ -4,26 +4,23 @@
 # lists and a variety of restraints.
 
 from __future__ import print_function
-import IMP.kernel
 import IMP.atom
 import IMP.core
-import random
 import RMF
 import IMP.container
 import IMP.rmf
-import IMP.base
 import sys
 
-IMP.base.setup_from_argv(sys.argv, "Chain example")
+IMP.setup_from_argv(sys.argv, "Chain example")
 
 # A trivial example that constructs a set of particles which are restrained
 # to form a chain via bonds between successive particles. In addition
 # the head and the tail of the chain are restrained to be close to one
 # another.
 
-IMP.base.set_log_level(IMP.base.TERSE)
-m = IMP.kernel.Model()
-m.set_log_level(IMP.base.SILENT)
+IMP.set_log_level(IMP.TERSE)
+m = IMP.Model()
+m.set_log_level(IMP.SILENT)
 h = IMP.atom.Hierarchy.setup_particle(m, m.add_particle("root"))
 # The particles in the chain
 ps = IMP.core.create_xyzr_particles(m, 10, 1.0)
@@ -32,11 +29,11 @@ for p in ps:
     h.add_child(IMP.atom.Hierarchy.setup_particle(p))
     # things are expected to have mass
     IMP.atom.Mass.setup_particle(p, 1)
-chain = IMP.container.ListSingletonContainer(ps, "chain")
+chain = IMP.container.ListSingletonContainer(m, ps, "chain")
 
 restraints = []
 # create a spring between successive particles
-bonds = IMP.container.ConsecutivePairContainer(ps)
+bonds = IMP.container.ConsecutivePairContainer(m, ps)
 hdps = IMP.core.HarmonicDistancePairScore(2, 1)
 chainr = IMP.container.PairsRestraint(hdps, bonds)
 chainr.set_name("The chain restraint")
@@ -51,8 +48,9 @@ lr = IMP.container.PairsRestraint(IMP.core.SoftSpherePairScore(1), nbl,
 restraints.append(lr)
 
 # Tie the ends of the chain
-tie = IMP.core.PairRestraint(IMP.core.HarmonicDistancePairScore(3, 1),
-                             (ps[0], ps[-1]))
+tie = IMP.core.PairRestraint(m, IMP.core.HarmonicDistancePairScore(3, 1),
+                             (ps[0].get_particle_index(),
+                              ps[-1].get_particle_index()))
 tie.set_name("tie ends")
 restraints.append(tie)
 
