@@ -67,10 +67,10 @@ function computeIndex($word)
   // Simple hashing that allows for substring search
   if (strlen($word)<2) return -1;
   // high char of the index
-  $hi = ord($word{0});
+  $hi = ord($word[0]);
   if ($hi==0) return -1;
   // low char of the index
-  $lo = ord($word{1});
+  $lo = ord($word[1]);
   if ($lo==0) return -1;
   // return index
   return $hi*256+$lo;
@@ -207,7 +207,7 @@ function combine_results($results,&$docs)
 function filter_results($docs,&$requiredWords,&$forbiddenWords)
 {
   $filteredDocs=array();
-  while (list ($key, $val) = each ($docs)) 
+  foreach ($docs as $key => $val) 
   {
     $words = &$docs[$key]["words"];
     $copy=1; // copy entry by default
@@ -328,8 +328,8 @@ function run_query($query)
   $word=strtok($query," ");
   while ($word) // for each word in the search query
   {
-    if (($word{0}=='+')) { $word=substr($word,1); $requiredWords[]=$word; }
-    if (($word{0}=='-')) { $word=substr($word,1); $forbiddenWords[]=$word; }
+    if (($word[0]=='+')) { $word=substr($word,1); $requiredWords[]=$word; }
+    if (($word[0]=='-')) { $word=substr($word,1); $forbiddenWords[]=$word; }
     if (!in_array($word,$foundWords))
     {
       $foundWords[]=$word;
